"""
Program  : SDMinP
Version  : 1.0
Date     : 16.03.2005
Purpose  : Adjustment of the multiple type I error (FWER)
Programer: Markus Obreiter
Contact  : m.obreiter@dkfz-heidelberg.de
Copyright (C) 2005 Deutsches Krebsforschungszentrum, DKFZ (German Cancer
Research Center), Division of Clinical
Epidemiology

This program is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your option)
any later version. 
This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. 

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.

A copy of the GNU Public License is attached to the program documentation.
"""

"""this file is used to start the program"""
import config , environment, control, sys, os.path, string, time

print 
print "SDMinP, version 1.0"
sCopyR = "Copyright (C) 2005  Deutsches Krebsforschungszentrum, DKFZ (German Cancer Research Center),"
sCopyR += " Division of Clinical Epidemiology"
print sCopyR
print
sLicense =  "SDMinP comes with ABSOLUTELY NO WARRANTY. This is free software, "
sLicense += "and you are welcome to redistribute it under certain conditions. "
sLicense += "For details see the GNU general public licenses. "
sLicense += "You should have received a copy of the GNU General Public License "
sLicense += "along with this program; if not, write to the Free Software Foundation, "
sLicense += "Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA."
print sLicense
print "A copy of the GNU Public License is attached to the program documentation."
print

# configuration object, basis information comes from on configuration file
CONFIGPATH = "../conf/configuration.conf"
if not os.path.isfile (CONFIGPATH): sys.exit ("No configuration file found in %s." %CONFIGPATH)

# evaluate input parameters, check for *.data input files
if  len(sys.argv) < 2:
    print "Please, specify at least one input file."
    sys.exit("Program aborted.")    
elif len(sys.argv) > 2:
    print "More than one input file specified."
    for p in sys.argv[1:]: print " --> " + str(p)
    print "Please, specify only one input file."
    sys.exit("Program aborted.")

inputDataFile = str(sys.argv[1])
if not inputDataFile:
    print "No input file specified."
    sys.exit("Program aborted.")

# check the file
if not os.path.isfile(inputDataFile):
    print
    print "Specified file not found."
    print "--> '%s'" %inputDataFile
    sys.exit("Program aborted.")

# start
try:
    cfg = config.Config(CONFIGPATH, inputDataFile)
except Exception, e:
    print        
    print "--> Invalid parameters in configuration file. Please check it."
    sys.exit (str(e))

print "Step down minP adjusted p-values will be computed for"
print " -> %s" %str(inputDataFile)
if cfg.interactiveDialog:
    if not string.strip(raw_input("Start calculation (type 'y')? ")) in ["Y", "y"]: sys.exit("Program terminated.")
    
# environment object to set directories
env = environment.Environment(cfg)
env.createDirectoryEnvironment()
# actual calculation of the program
ctrl = control.Control(cfg)    
ctrl.run()

if cfg.cleanSplitFileDirectory:        
    print time.asctime() + " - Cleaning split file directory .."
    env.emptySplitFileDirectory()
    print time.asctime() + " - Cleaning split file directory finished."
else:
    print
    print "--> NOTE: Cleaning split file directory is NOT ACTIVATED. <--"
    print "-->       There might be some files staying there.        <--"

print
if cfg.logRawPCalc or cfg.logSorting or cfg.logStepDown or cfg.logGlobalPvalCalc:
    print
    print "LOGGING ENABLED (time consuming), see ../log" 
    print

print
print "Result(s) stored in "
print " --> " + cfg.resultFile_Path
if cfg.resultRFormat: print " --> " + cfg.rformatFile_Path
# end
print "Program finished."
